<?php 

namespace Schaffen\SerasaRemessa\Http\Advanced\PF;
use GuzzleHttp\Client;
use Schaffen\SerasaRemessa\Http\Advanced\PF\Blocks\ClosingBlock;
use Schaffen\SerasaRemessa\Http\Advanced\PF\Blocks\MainBlock;
use Schaffen\SerasaRemessa\Http\Advanced\PF\Blocks\OpeningBlock;
use Schaffen\SerasaRemessa\Http\Advanced\PF\Blocks\RegN001;
use Schaffen\SerasaRemessa\Http\Advanced\PF\Blocks\RegN003;
use Schaffen\SerasaRemessa\Http\Advanced\PF\Blocks\RegP002;
use Schaffen\SerasaRemessa\Http\Advanced\PF\Blocks\RegP006;

class Query {
    private $mainBlock;
    private $regP002;
    private $regP006;
    private $closingBlock;
    private $openingBlock;

    public function __construct($logon, $password, array $config) {
        $this->openingBlock = new OpeningBlock($logon, $password);
        $this->mainBlock = new MainBlock($config);

        $this->setP002();
        $this->regP006 = new RegP006([]);

        $this->closingBlock = new ClosingBlock();
    }

    public function setP002() {
        /**
         * Adicionar opções de configuração para selecionar informações adicionais
         * Será necesário gerenciar a quantidade de blocos P002
         * Valores fixos por hora
         * BPTM -> Comprometimento de Renda
         * BPPG -> Capacidade de Pagamento 
         * BPHM –> Score Positivo PF
         * BPRD -> Renda estimada
         */
        $this->regP002 = new RegP002("BPTM", "BPPG", "BPHM", "BPRD");
    }

    private function makeOpeningBlock() {
        return $this->openingBlock->toString();
    }
    private function makeMainBlock() {
        return $this->mainBlock->toString();
    }
    
    private function makeRegP002() {
        return $this->regP002->toString();
    }

    private function makeRegP006() {
        return $this->regP006->toString();
    }

    private function makeClosingBlock() {
        return $this->closingBlock->toString();
    }

    public function make() {
        $openingBlock = $this->makeOpeningBlock();
        $mainBlock = $this->makeMainBlock();
        $regP002 = $this->makeRegP002();
        $regP006 = $this->makeRegP006();

        $closingBlock = $this->makeClosingBlock();
        
        return $openingBlock . $mainBlock . $regP002 . $regP006 . $closingBlock;
    }

    public function send($url) {
        try {
            $p = $this->make();
            $client = new Client();
            $body = $client->request('POST', $url, ['query' => ['p' => $p]])->getBody();
            return Response::load($body)->translate();
        } catch(Exception $e) {
            return "Ocorreu um erro inesperado, contate o suporte.";
        }
    }
}